@@ -6,8 +6,8 @@ use warnings;
 use utf8;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
-use Mouse;
-use MouseX::Types::Path::Class;
+use Moo;
+use App::Sqitch::Types qw(Str Int ArrayRef HashRef Dir Bool Maybe);
 use Path::Class;
 use Try::Tiny;
 use File::Path qw(make_path);
@@ -16,33 +16,29 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.995';
+our $VERSION = '0.996';
 
 has requires => (
     is       => 'ro',
-    isa      => 'ArrayRef[Str]',
-    required => 1,
+    isa      => ArrayRef[Str],
     default  => sub { [] },
 );
 
 has conflicts => (
     is       => 'ro',
-    isa      => 'ArrayRef[Str]',
-    required => 1,
+    isa      => ArrayRef[Str],
     default  => sub { [] },
 );
 
 has note => (
     is       => 'ro',
-    isa      => 'ArrayRef[Str]',
-    required => 1,
+    isa      => ArrayRef[Str],
     default  => sub { [] },
 );
 
 has variables => (
     is       => 'ro',
-    isa      => 'HashRef',
-    required => 1,
+    isa      => HashRef,
     lazy     => 1,
     default  => sub {
         shift->sqitch->config->get_section( section => 'add.variables' );
@@ -51,28 +47,25 @@ has variables => (
 
 has template_directory => (
     is  => 'ro',
-    isa => 'Maybe[Path::Class::Dir]',
+    isa => Maybe[Dir],
 );
 
 has template_name => (
     is       => 'ro',
-    isa      => 'Str',
-    required => 1,
+    isa      => Str,
     lazy     => 1,
     default  => sub { shift->sqitch->engine_key },
 );
 
 has with_scripts => (
     is       => 'ro',
-    isa      => 'HashRef',
-    required => 1,
+    isa      => HashRef,
     default  => sub { {} },
 );
 
 has templates => (
     is       => 'ro',
-    isa      => 'HashRef',
-    required => 1,
+    isa      => HashRef,
     lazy     => 1,
     default  => sub {
         my $self = shift;
@@ -82,7 +75,7 @@ has templates => (
 
 has open_editor => (
     is       => 'ro',
-    isa      => 'Bool',
+    isa      => Bool,
     lazy     => 1,
     default  => sub {
         shift->sqitch->config->get(
@@ -433,6 +426,28 @@ options for the C<add> command.
 Processes the configuration and command options and returns a hash suitable
 for the constructor.
 
+=head2 Attributes
+
+=head3 C<note>
+
+Text of the change note.
+
+=head3 C<requires>
+
+List of required changes.
+
+=head3 C<conflicts>
+
+List of conflicting changes.
+
+=head3 C<template_directory>
+
+Directory in which to find the change script templates.
+
+=head3 C<with_scripts>
+
+Hash reference indicating which scripts to create.
+
 =head2 Instance Methods
 
 =head3 C<execute>
@@ -441,7 +456,7 @@ for the constructor.
 
 Executes the C<add> command.
 
-=head2 C<all_templates>
+=head3 C<all_templates>
 
 Returns a hash reference of script names mapped to template files for all
 scripts that should be generated for the new change.
