@@ -4,24 +4,25 @@ use 5.010;
 use strict;
 use warnings;
 use utf8;
-use Mouse;
-use Mouse::Util::TypeConstraints;
+use Moo;
+use App::Sqitch::Types qw(URI Maybe Str Bool HashRef);
 use Locale::TextDomain qw(App-Sqitch);
+use Type::Utils qw(enum);
 use App::Sqitch::X qw(hurl);
 use List::Util qw(first);
 use namespace::autoclean;
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.995';
+our $VERSION = '0.996';
 
 has target => (
     is  => 'ro',
-    isa => 'Str',
+    isa => Str,
 );
 
 has to_change => (
     is  => 'ro',
-    isa => 'Str',
+    isa => Str,
 );
 
 has mode => (
@@ -36,22 +37,19 @@ has mode => (
 
 has log_only => (
     is       => 'ro',
-    isa      => 'Bool',
-    required => 1,
+    isa      => Bool,
     default  => 0,
 );
 
 has verify => (
     is       => 'ro',
-    isa      => 'Bool',
-    required => 1,
+    isa      => Bool,
     default  => 0,
 );
 
 has variables => (
     is       => 'ro',
-    isa      => 'HashRef',
-    required => 1,
+    isa      => HashRef,
     lazy     => 1,
     default  => sub {
         shift->sqitch->config->get_section( section => 'deploy.variables' );
@@ -167,6 +165,28 @@ works, read on.
 Returns a list of L<Getopt::Long> option specifications for the command-line
 options for the C<deploy> command.
 
+=head2 Attributes
+
+=head3 C<log_only>
+
+Boolean indicating whether to log the deploy without running the scripts.
+
+=head3 C<mode>
+
+Deploy mode, one of "change", "tag", or "all".
+
+=head3 C<target>
+
+The deployment target URI.
+
+=head3 C<to_change>
+
+Change up to which to deploy.
+
+=head3 C<verify>
+
+Boolean indicating whether or not to run verify scripts after each change.
+
 =head2 Instance Methods
 
 =head3 C<execute>
