@@ -1,7 +1,7 @@
 package App::Sqitch::Engine::oracle;
 
 use 5.010;
-use Mouse;
+use Moo;
 use utf8;
 use Path::Class;
 use DBI;
@@ -10,13 +10,12 @@ use App::Sqitch::X qw(hurl);
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::Plan::Change;
 use List::Util qw(first);
+use App::Sqitch::Types qw(DBH Dir ArrayRef);
 use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
-sub dbh; # required by DBIEngine;
-with 'App::Sqitch::Role::DBIEngine';
 
-our $VERSION = '0.995';
+our $VERSION = '0.996';
 
 BEGIN {
     # We tell the Oracle connector which encoding to use. The last part of the
@@ -49,22 +48,21 @@ has '+destination' => (
     },
 );
 
-has sqlplus => (
+has _sqlplus => (
     is         => 'ro',
-    isa        => 'ArrayRef',
+    isa        => ArrayRef,
     lazy       => 1,
-    required   => 1,
-    auto_deref => 1,
     default    => sub {
         my $self = shift;
         [ $self->client, qw(-S -L /nolog) ];
     },
 );
 
+sub sqlplus { @{ shift->_sqlplus } }
+
 has tmpdir => (
     is       => 'ro',
-    isa      => 'Path::Class::Dir',
-    required => 1,
+    isa      => Dir,
     lazy     => 1,
     default  => sub {
         require File::Temp;
@@ -83,7 +81,7 @@ sub default_client {
 
 has dbh => (
     is      => 'rw',
-    isa     => 'DBI::db',
+    isa     => DBH,
     lazy    => 1,
     default => sub {
         my $self = shift;
@@ -119,11 +117,13 @@ has dbh => (
                     return;
                 },
             },
-            $uri->query_params,
         });
     }
 );
 
+# Need to wait until dbh is defined.
+with 'App::Sqitch::Role::DBIEngine';
+
 sub _log_tags_param {
     [ map { $_->format_name } $_[1]->tags ];
 }
@@ -704,8 +704,7 @@ sub _capture {
     return wantarray ? @out : \@out;
 }
 
-__PACKAGE__->meta->make_immutable;
-no Mouse;
+1;
 
 __END__
 
@@ -720,7 +719,7 @@ App::Sqitch::Engine::oracle - Sqitch Oracle Engine
 =head1 Description
 
 App::Sqitch::Engine::oracle provides the Oracle storage engine for Sqitch. It
-supports Oracle 8.4.0 and higher.
+supports Oracle 10g and higher.
 
 =head1 Interface
 
@@ -739,6 +738,11 @@ has not.
 
 Initializes a database for Sqitch by installing the Sqitch registry schema.
 
+=head3 C<sqlplus>
+
+Returns a list containing the the C<sqlplus> client and options to be passed
+to it. Used internally when executing scripts.
+
 =head1 Author
 
 David E. Wheeler <david@justatheory.com>
