@@ -2,7 +2,6 @@ package App::Sqitch::Plan;
 
 use 5.010;
 use utf8;
-use App::Sqitch::DateTime;
 use App::Sqitch::Plan::Tag;
 use App::Sqitch::Plan::Change;
 use App::Sqitch::Plan::Blank;
@@ -15,10 +14,11 @@ use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use List::MoreUtils qw(uniq any);
 use namespace::autoclean;
-use Mouse;
+use Moo;
+use App::Sqitch::Types qw(Str Int HashRef ChangeList LineList Maybe Sqitch URI);
 use constant SYNTAX_VERSION => '1.0.0-b2';
 
-our $VERSION = '0.995';
+our $VERSION = '0.996';
 
 # Like [:punct:], but excluding _. Copied from perlrecharclass.
 my $punct = q{-!"#$%&'()*+,./:;<=>?@[\\]^`{|}~};
@@ -42,14 +42,14 @@ sub name_regex { $name_re }
 
 has sqitch => (
     is       => 'ro',
-    isa      => 'App::Sqitch',
+    isa      => Sqitch,
     required => 1,
     weak_ref => 1,
 );
 
 has _plan => (
     is         => 'rw',
-    isa        => 'HashRef',
+    isa        => HashRef,
     builder    => 'load',
     init_arg   => 'plan',
     lazy       => 1,
@@ -58,9 +58,8 @@ has _plan => (
 
 has _changes => (
     is       => 'ro',
-    isa      => 'App::Sqitch::Plan::ChangeList',
+    isa      => ChangeList,
     lazy     => 1,
-    required => 1,
     default  => sub {
         App::Sqitch::Plan::ChangeList->new(@{ shift->_plan->{changes} }),
     },
@@ -68,9 +67,8 @@ has _changes => (
 
 has _lines => (
     is       => 'ro',
-    isa      => 'App::Sqitch::Plan::LineList',
+    isa      => LineList,
     lazy     => 1,
-    required => 1,
     default  => sub {
         App::Sqitch::Plan::LineList->new(@{ shift->_plan->{lines} }),
     },
@@ -78,15 +76,13 @@ has _lines => (
 
 has position => (
     is       => 'rw',
-    isa      => 'Int',
-    required => 1,
+    isa      => Int,
     default  => -1,
 );
 
 has project => (
     is       => 'ro',
-    isa      => 'Str',
-    required => 1,
+    isa      => Str,
     lazy     => 1,
     default  => sub {
         shift->_plan->{pragmas}{project};
@@ -95,13 +91,12 @@ has project => (
 
 has uri => (
     is       => 'ro',
-    isa      => 'Maybe[URI]',
-    required => 0,
+    isa      => Maybe[URI],
     lazy     => 1,
     default  => sub {
         my $uri = shift->_plan->{pragmas}{uri} || return;
         require URI;
-        URI->new($uri);
+        'URI'->new($uri);
     }
 );
 
@@ -120,7 +115,7 @@ sub load {
             unless -e $file;
         hurl plan => __x('Plan file {file} is not a regular file', file => $file)
             unless -f $file;
-        $file->open('<:utf8_strict') or hurl plan => __x(
+        $file->open('<:utf8_strict') or hurl io => __x(
             'Cannot open {file}: {error}',
             file  => $file,
             error => $!
@@ -168,7 +163,7 @@ sub _parse {
 
     # Use for raising syntax error exceptions.
     my $raise_syntax_error = sub {
-        hurl plan => __x(
+        hurl parse => __x(
             'Syntax error in {file} at line {lineno}: {error}',
             file   => $file,
             lineno => $fh->input_line_number,
@@ -249,7 +244,7 @@ sub _parse {
     }
 
     # Should have valid project pragma.
-    hurl plan => __x(
+    hurl parse => __x(
         'Missing %project pragma in {file}',
         file => $file,
     ) unless $pragmas{project};
@@ -330,6 +325,7 @@ sub _parse {
         )) if $params{name} =~ /^[0-9a-f]{40}/;
 
         # Assemble the timestamp.
+        require App::Sqitch::DateTime;
         $params{timestamp} = App::Sqitch::DateTime->new(
             year      => delete $params{yr},
             month     => delete $params{mo},
@@ -558,7 +554,7 @@ sub check_changes {
     }
 
     # Throw the exception with all of the errors.
-    hurl plan => join(
+    hurl parse => join(
         "\n  ",
         __n(
             'Dependency error detected:',
@@ -572,7 +568,7 @@ sub check_changes {
 sub open_script {
     my ( $self, $file ) = @_;
     # return has higher precedence than or, so use ||.
-    return $file->open('<:utf8_strict') || hurl plan => __x(
+    return $file->open('<:utf8_strict') || hurl io => __x(
         'Cannot open {file}: {error}',
         file  => $file,
         error => $!,
@@ -594,7 +590,6 @@ sub last_tagged_change { shift->_changes->last_tagged_change }
 
 sub search_changes {
     my ( $self, %p ) = @_;
-    my $meta = App::Sqitch::Plan::Change->meta;
 
     my $reverse = 0;
     if (my $d = delete $p{direction}) {
@@ -605,14 +600,13 @@ sub search_changes {
 
     # Limit with regular expressions?
     my @filters;
-    for my $spec (
-        [ planner => 'planner_name' ],
-        [ name    => 'name'         ],
-    ) {
-        my $regex = delete $p{ $spec->[0] } // next;
+    if (my $regex = delete $p{planner}) {
         $regex = qr/$regex/;
-        my $attr = $meta->find_attribute_by_name( $spec->[1] );
-        push @filters => sub { $attr->get_value($_[0]) =~ $regex };
+        push @filters => sub { $_[0]->planner_name =~ $regex };
+    }
+    if (my $regex = delete $p{name}) {
+        $regex = qr/$regex/;
+        push @filters => sub { $_[0]->name =~ $regex };
     }
 
     # Match events?
@@ -957,13 +951,13 @@ sub write_to {
         );
     }
 
-    my $fh = $file->open('>:utf8_strict') or hurl plan => __x(
+    my $fh = $file->open('>:utf8_strict') or hurl io => __x(
         'Cannot open {file}: {error}',
         file  => $file,
         error => $!
     );
     $fh->say($_->as_string) for @lines;
-    $fh->close or hurl plan => __x(
+    $fh->close or hurl io => __x(
         '"Error closing {file}: {error}',
         file => $file,
         error => $!,
@@ -971,8 +965,7 @@ sub write_to {
     return $self;
 }
 
-__PACKAGE__->meta->make_immutable;
-no Mouse;
+1;
 
 __END__
 
