@@ -2,38 +2,39 @@ package App::Sqitch::X;
 
 use 5.010;
 use utf8;
-use Moose;
+use Moo;
+use Types::Standard qw(Str Int);
 use Sub::Exporter::Util ();
+use Throwable 0.200009;
 use Sub::Exporter -setup => [qw(hurl)];
-use Role::HasMessage 0.005;
-use Role::Identifiable::HasIdent 0.005;
-use Role::Identifiable::HasTags 0.005;
 use overload '""' => 'as_string';
 
-our $VERSION = '0.995';
+our $VERSION = '0.996';
 
 has message => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has exitval => (
-    is       => 'ro',
-    isa      => 'Int',
-    required => 1,
-    default  => 2,
+    is      => 'ro',
+    isa     => Int,
+    default => 2,
 );
 
 
 with qw(
     Throwable
-    Role::HasMessage
-    Role::Identifiable::HasIdent
     StackTrace::Auto
 );
 
-has '+ident' => (default => 'DEV');
+has ident => (
+  is      => 'ro',
+  isa     => Str,
+  default => 'DEV'
+);
+
 has '+previous_exception' => (init_arg => 'previous_exception')
     if Throwable->VERSION < 0.200007;
 
@@ -60,8 +61,7 @@ sub as_string {
     );
 }
 
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
-no Moose;
+1;
 
 __END__
 
